widget.onremove = removed;

function init() {
  // Localize
  document.getElementById("siteTitle").innerText = getLocalizedString("title");
  document.getElementById("homePageLabel").innerText = getLocalizedString("homePageURL");
  document.getElementById("bookmarksBarLabel").innerText = getLocalizedString("bookmarksBar");
  document.getElementById("shiiraCheckboxDiv").childNodes[1].nodeValue = getLocalizedString("useShiiraBookmark");
  document.getElementById("safariCheckboxDiv").childNodes[1].nodeValue = getLocalizedString("useSafariBookmark");
  document.getElementById("backgroundLabel").innerText = getLocalizedString("backgroundLabel");
  document.getElementById("version").innerText = getLocalizedString("version");
  
  // Get web view
  var webView = document.getElementById("webView");
  
  // Create buttons
  createButton(document.getElementById("goBack"), goBack);
  createButton(document.getElementById("goForward"), goForward);
  createButton(document.getElementById("reloadPage"), reloadPage);
  createButton(document.getElementById("stopLoading"), stopLoading);
  createButton(document.getElementById("shadeWindow"), shadeWindow);
  createButton(document.getElementById("bookmark"), showBookmark);
  createButton(document.getElementById("openBrowser"), openBrowser);
  createButton(document.getElementById("goHome"), goHome);
  
  // Create info button
  var infoRollie = document.getElementById("infoRollie");
  createInfoRollieButton(infoRollie, "black");
  var front = document.getElementById("front");
  var info = document.getElementById("info");
  createInfoButton(front, info, "black");
  
  // Create done button
  var done = document.getElementById("done");
  createGenericButton(done, getLocalizedString("done"), showFrontside);
  
  // Set handler
  document.getElementById("webView").onFrameLoadName = "onFrameLoad";
  
  // Set home page
  var homePageURL = widget.preferenceForKey("homePage");
  if (homePageURL) {
    document.getElementById("homePageInput").value = homePageURL;
    
    // Load home page
    webView.loadURL(homePageURL);
  }
  
  // Check bookmarks
  var select = document.getElementById("bookmarksBarSelect");
  var option;
  var hasShiira = webView.hasBookmarkOfBrowser(0);
  if (hasShiira) {
    option = document.createElement("option");
    option.innerText = getLocalizedString("shiira");
    select.appendChild(option);
  }
  else {
    document.getElementById("shiiraCheckbox").disabled = true;
  }
  
  var hasSafari = webView.hasBookmarkOfBrowser(1);
  if (hasSafari) {
    option = document.createElement("option");
    option.innerText = getLocalizedString("safari");
    select.appendChild(option);
  }
  else {
    document.getElementById("safariCheckbox").disabled = true;
  }
  
  var selectedBookmarksBar = widget.preferenceForKey("bookmarksBar");
  if (select.length > selectedBookmarksBar) {
    select.childNodes[selectedBookmarksBar].selected = true;
  }
  
  var showShiira;
  showShiira = widget.preferenceForKey("showShiira");
  if (showShiira && showShiira != undefined) {
    document.getElementById("shiiraCheckbox").checked = showShiira;
  }
  
  var showSafari;
  showSafari = widget.preferenceForKey("showSafari");
  if (showSafari && showSafari != undefined) {
    document.getElementById("safariCheckbox").checked = showSafari;
  }
  
  // Update background
  select = document.getElementById("backgroundSelect");
  
  option = document.createElement("option");
  option.innerText = getLocalizedString("green");
  select.appendChild(option);
  
  option = document.createElement("option");
  option.innerText = getLocalizedString("silver");
  select.appendChild(option);
  
  var background = widget.preferenceForKey(widget.identifier + "background");
  if (background == null) {
    background = widget.preferenceForKey("background");
  }
  if (select.length > background) {
    select.childNodes[background].selected = true;
  }
  widget.setPreferenceForKey(background, widget.identifier+"background");
  
  updateBackground();
  
  // Update appearance
  updateAppearance();
}

function removed() {
  widget.setPreferenceForKey(null, widget.identifier+"background");
}

function createButton(element, handler) {
  element.src = "Images/" + element.name + ".png";
  
  element.addEventListener("mouseover", mouseOver, false);
  element.addEventListener("mouseout", mouseOut, false);
  element.addEventListener("mousedown", mouseDown, false);
  element.addEventListener("mouseup", mouseUp, false);
  
  element.buttonClickAction = handler;
}

function mouseOver(event) {
}

function mouseOut(event) {
}

function mouseDown(event) {
  var element = event.toElement;
  element.src = "Images/" + element.name + "Pressed.png";
  element.isPressed = 1;
}

function mouseUp(event) {
  var element = event.toElement;
  element.src = "Images/" + element.name + ".png";
  element.isPressed = 0;
  
  element.buttonClickAction();
}

function backgroundName() {
  var background = widget.preferenceForKey(widget.identifier + "background");
  if (background == null) {
    background = widget.preferenceForKey("background");
  }
  
  if (background == 0) {
    return "Images/green.png";
  }
  return "Images/silver.png";
}

function shadedBackgroundName() {
  var background = widget.preferenceForKey(widget.identifier + "background");
  if (background == null) {
    background = widget.preferenceForKey("background");
  }
  
  if (background == 0) {
    return "Images/greenShaded.png";
  }
  return document.getElementById("background").src = "Images/silverShaded.png";
}

function isWindowShaded() {
  var backgroundSrc;
  backgroundSrc = document.getElementById("background").src;
  
  if (backgroundSrc.lastIndexOf("Default.png") != -1) {
    return false;
  }
  
  if (backgroundSrc.lastIndexOf(shadedBackgroundName()) != -1) {
    return true;
  }
  return false;
}

function goBack(event) {
  document.getElementById("webView").goBack();
}

function goForward(event) {
  document.getElementById("webView").goForward();
}

function goHome(event) {
  var homePageURL = widget.preferenceForKey("homePage");
  if (homePageURL) {
    document.getElementById("homePageInput").value = homePageURL;
    
    // Load home page
    webView.loadURL(homePageURL);
  }
}

function reloadPage(event) {
  document.getElementById("webView").reloadPage();
}

function stopLoading(event) {
  document.getElementById("webView").stopLoading();
}

function shadeWindow(event) {
alert("shadeWindow");
  var element;
  element = document.getElementById("background");
  
  // Show window
  if (isWindowShaded()) {
    element.src = backgroundName();
    element.style.width = 520;
    element.style.height = 440;
    resizeTo(520, 440);
    
    // Hide buttons and text field
    document.getElementById("goBack").style.visibility = "visible";
    document.getElementById("goForward").style.visibility = "visible";
    document.getElementById("reloadPage").style.visibility = "visible";
    document.getElementById("stopLoading").style.visibility = "visible";
    document.getElementById("URLField").style.visibility = "visible";
    
    // Move button and title
    element = document.getElementById("shadeWindow");
    element.style.left = 483;
    element.style.top = 55;
    element = document.getElementById("siteTitle");
    element.style.left = 21;
    element.style.top = 56;
  }
  // Shade window
  else {
    element.src = shadedBackgroundName();
    element.style.width = 520;
    element.style.height = 68;
    resizeTo(520, 68);
    
    // Hide buttons and text field
    document.getElementById("goBack").style.visibility = "hidden";
    document.getElementById("goForward").style.visibility = "hidden";
    document.getElementById("reloadPage").style.visibility = "hidden";
    document.getElementById("stopLoading").style.visibility = "hidden";
    document.getElementById("URLField").style.visibility = "hidden";
    
    // Move button and title
    element = document.getElementById("shadeWindow");
    element.style.left = 483;
    element.style.top = 21;
    element = document.getElementById("siteTitle");
    element.style.left = 21;
    element.style.top = 22;
  }
}

function showBookmark(event) {
  var bookmarksBar = 0;
  if (document.getElementById("bookmarksBarSelect").length > 0) {
    bookmarksBar = document.getElementById("bookmarksBarSelect").selectedIndex;
  }
  
  var showShiira = false;
  if (!document.getElementById("shiiraCheckbox").disabled) {
    showShiira = document.getElementById("shiiraCheckbox").checked;
  }
  
  var showSafari = false;
  if (!document.getElementById("safariCheckbox").disabled) {
    showSafari = document.getElementById("safariCheckbox").checked;
  }
  
  document.getElementById("webView").showBookmarks(bookmarksBar, showShiira, showSafari);
}

function openBrowser(event) {
  var URL = document.getElementById("URLField").value;
  if (URL && URL.length > 0) {
    widget.openURL(URL);
  }
}

function loadPage(event) {
  var URL = document.getElementById("URLField").value;
  if (URL == null) return;
  
  document.getElementById("webView").loadURL(URL);
}

function setHomePage(event) {
  var homePageURL = document.getElementById("homePageInput").value;
  if (homePageURL == null) return;
  
  widget.setPreferenceForKey(homePageURL, "homePage");
}

function setBookmarksBar(event) {
  var selectedBookmarksBar = document.getElementById("bookmarksBarSelect").selectedIndex;
  if (selectedBookmarksBar == null) return;
  
  widget.setPreferenceForKey(selectedBookmarksBar, "bookmarksBar");
}

function setShiiraBookmark(event) {
  var showShiira = document.getElementById("shiiraCheckbox").checked;
  
  widget.setPreferenceForKey(showShiira, "showShiira");
}

function setSafariBookmark(event) {
  var showSafari = document.getElementById("safariCheckbox").checked;
  
  widget.setPreferenceForKey(showSafari, "showSafari");
}

function setBackground(event) {
  var background = document.getElementById("backgroundSelect").selectedIndex;
  if (background == null) return;
  
  widget.setPreferenceForKey(background, "background");
  widget.setPreferenceForKey(background, widget.identifier+"background");
  
  updateBackground();
}

var disabledOpacity = 0.5;

function updateBackground() {
  var src;
  if (isWindowShaded()) {
    src = shadedBackgroundName();
  }
  else {
    src = backgroundName();
  }
  
  document.getElementById("background").src = src;
}

function updateAppearance() {
  // Get web view
  var webView = document.getElementById("webView");
  
  // Get URL
  var URL = webView.URL();
  if (URL) {
    document.getElementById("URLField").value = URL;
  }
  
  // Get title
  var title = webView.title();
  if (title) {
    document.getElementById("siteTitle").innerText = title;
  }
  
  // Check buttons availability
  var button;
  
  button = document.getElementById("goBack");
  if (webView.canGoBack()) button.style.opacity = 1.0;
  else button.style.opacity = disabledOpacity;
  
  button = document.getElementById("goForward");
  if (webView.canGoForward()) button.style.opacity = 1.0;
  else button.style.opacity = disabledOpacity;
  
  button = document.getElementById("reloadPage");
  if (!webView.isLoading()) button.style.opacity = 1.0;
  else button.style.opacity = disabledOpacity;
  
  button = document.getElementById("stopLoading");
  if (webView.isLoading()) button.style.opacity = 1.0;
  else button.style.opacity = disabledOpacity;
}

function onFrameLoad(notificationName) {
  if (notificationName == "didStartProvisionalLoad") {
  }
  else if (notificationName == "didCommitLoad") {
    updateAppearance();
  }
  else if (notificationName == "serverRedirected") {
    updateAppearance();
  }
  else if (notificationName == "didFinishLoad") {
    updateAppearance();
  }
  else if (notificationName == "didFailProvisionalLoad") {
    updateAppearance();
  }
  else if (notificationName == "didFailLoad") {
    updateAppearance();
  }
}

function showBackside(event) {
  var front = document.getElementById("front");
  var back = document.getElementById("back");
  
  if (window.widget) {
    widget.prepareForTransition("ToBack");
  }
  
  front.style.visibility = "hidden";
  back.style.visibility = "visible";
  
  // Hide buttons and text field
  document.getElementById("goBack").style.visibility = "hidden";
  document.getElementById("goForward").style.visibility = "hidden";
  document.getElementById("reloadPage").style.visibility = "hidden";
  document.getElementById("stopLoading").style.visibility = "hidden";
  document.getElementById("URLField").style.visibility = "hidden";
  
  if (window.widget) {
    setTimeout("widget.performTransition();", 0);
  }
  
  var infoRollie = document.getElementById("infoRollie");
  infoRollie.style.opacity = "0.0";
}

function showFrontside(event) {
  var front = document.getElementById("front");
  var back = document.getElementById("back");
  
  if (window.widget) {
  	widget.prepareForTransition("ToFront");
  }
  
  front.style.visibility = "visible";
  back.style.visibility = "hidden";
  
    // Hide buttons and text field
  document.getElementById("goBack").style.visibility = "visible";
  document.getElementById("goForward").style.visibility = "visible";
  document.getElementById("reloadPage").style.visibility = "visible";
  document.getElementById("stopLoading").style.visibility = "visible";
  document.getElementById("URLField").style.visibility = "visible";
  
  if (window.widget) {
    setTimeout("widget.performTransition();", 0);
  }
}

function bodyKeyDown(event)
{
    // Ignore page up and page down key
    if (event.keyCode == 33 || event.keyCode == 34) {
alert("igonre key");
        event.stopPropagation();
        event.preventDefault();
        return;
    }
}
